package com.wd.workoffice.ui.activity.mes.work;

import android.content.Intent;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;

import com.alibaba.fastjson.JSON;
import com.chad.library.adapter.base.BaseQuickAdapter;
import com.wd.workoffice.R;
import com.wd.workoffice.app.BaseMesBean;
import com.wd.workoffice.app.WorkToolBarActivity;
import com.wd.workoffice.bean.mesBean.FaultTypeBean;
import com.wd.workoffice.bean.mesBean.WorkFactoryBean;
import com.wd.workoffice.bean.mesBean.WorkPeopleBean;
import com.wd.workoffice.retrofit.RtfUtils;
import com.wd.workoffice.retrofit.WorkObserver;
import com.wd.workoffice.ui.adapter.FauliTypeAdapter;
import com.wd.workoffice.ui.adapter.WorkDepManageAdapter;
import com.wd.workoffice.ui.adapter.WorkFactoryAdapter;
import com.wd.workoffice.ui.adapter.WorkPeopleAdapter;
import com.wd.workoffice.util.WorkUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import flexible.xd.android_base.network.rtfhttp.Transformer;
import io.reactivex.disposables.Disposable;

/**
 * 员工搜索
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class WorkTaskChoosePeopleActivity extends WorkToolBarActivity {

    @BindView(R.id.et_key)
    EditText etKey;
    @BindView(R.id.btn_search)
    Button btnSearch;
    @BindView(R.id.rv_client)
    RecyclerView rvClient;
    private Map<String, Object> param;
    private List<WorkPeopleBean.ListBean> clientList;
    private WorkPeopleAdapter clientAdapter;
    private int page = 1;
    private Map<String, Object> paramMap;

    @Override
    protected void initView() {
        ButterKnife.bind(this);
        rvClient.setLayoutManager(new LinearLayoutManager(this, RecyclerView.VERTICAL, false));

    }

    @Override
    protected void initData() {
        clientList = new ArrayList<>();
        clientAdapter = new WorkPeopleAdapter(R.layout.item_fault_search, clientList);
        clientAdapter.bindToRecyclerView(rvClient);
        clientAdapter.setEmptyView(R.layout.view_empty_content, rvClient);
        param = WorkUtils.pageMesKey();
        paramMap = WorkUtils.simpleParam();
        paramMap.put("userId", getIntent().getStringExtra("id"));
        param.put("paramMap", paramMap);
        param.put("pageNum", 1);
        getData();
    }

    private void getData() {
        RtfUtils.getMesRtf().userCraft("1", WorkUtils.convertMapToBody(param)).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseMesBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
            }

            @Override
            public void onFail(String errorMsg) {
                hideLoading();
                toast(errorMsg);
            }

            @Override
            public void onSuccess(BaseMesBean data) {
                hideLoading();
                if (!data.isSuccess()) {
                    toast(data.getMessage());
                    return;
                }
                List<WorkPeopleBean.ListBean> getList = JSON.parseObject(data.getData().toString(), WorkPeopleBean.class).getList();
                if (page == 1) {
                    clientList.clear();
                    clientList.addAll(getList);
                    clientAdapter.notifyDataSetChanged();
                    clientAdapter.loadMoreComplete();
                } else {
                    clientAdapter.loadMoreComplete();
                    clientList.addAll(getList);
                    clientAdapter.notifyDataSetChanged();
                }
                if (getList.size() == 0) {
                    clientAdapter.loadMoreEnd();
                } else {
                    page++;
                }
                toast("搜索成功");
            }
        });
    }

    @Override
    protected void initEvent() {
        clientAdapter.setOnLoadMoreListener(new BaseQuickAdapter.RequestLoadMoreListener() {
            @Override
            public void onLoadMoreRequested() {
                param.put("pageNum", page);
                getData();
            }
        }, rvClient);
        clientAdapter.setOnItemClickListener(new BaseQuickAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(BaseQuickAdapter adapter, View view, int position) {
                Intent intent = new Intent();
                intent.putExtra("data", JSON.toJSONString(clientList.get(position)));
                setResult(10001, intent);
                finish();
            }
        });
    }

    @Override
    protected int layoutId() {
        return R.layout.activity_mes_fault_search;
    }


    @OnClick(R.id.btn_search)
    public void onViewClicked() {
        paramMap.put("name", etKey.getText().toString());
        param.put("pageNum", 1);
        page = 1;
        getData();
    }
}
